`p`-adics
=======================

.. toctree::
   :maxdepth: 1

   sage/rings/padics/tutorial

   sage/rings/padics/factory

   sage/rings/padics/local_generic
   sage/rings/padics/padic_generic

   sage/rings/padics/generic_nodes
   sage/rings/padics/padic_base_generic
   sage/rings/padics/padic_extension_generic
   sage/rings/padics/eisenstein_extension_generic
   sage/rings/padics/unramified_extension_generic

   sage/rings/padics/padic_base_leaves
   sage/rings/padics/padic_extension_leaves

   sage/rings/padics/local_generic_element
   sage/rings/padics/padic_generic_element

   sage/rings/padics/padic_capped_relative_element
   sage/rings/padics/padic_capped_absolute_element
   sage/rings/padics/padic_fixed_mod_element

   sage/rings/padics/padic_ext_element
   sage/rings/padics/padic_ZZ_pX_element
   sage/rings/padics/padic_ZZ_pX_CR_element
   sage/rings/padics/padic_ZZ_pX_CA_element
   sage/rings/padics/padic_ZZ_pX_FM_element

   sage/rings/padics/pow_computer
   sage/rings/padics/pow_computer_ext
   sage/rings/padics/padic_printing
   sage/rings/padics/precision_error
   sage/rings/padics/misc

   sage/rings/padics/common_conversion
   sage/rings/padics/morphism

.. include:: ../footer.txt
